 
#include <EasyTransfer.h>

/* Motor controller inputs
 *  input 1     input 2    direction
      OFF         OFF        Motor Off
      ON          OFF        Forward
      OFF         ON         Reverse
      ON          ON         Not used
      
The Enable line can be used to turn the motor on, 
to turn it off and to control its speed. 
When the Enable line is at 5 Volts (1) the motor will be on. 
Grounding the Enable line (0) will turn the motor off.

To control the speed of the motor you apply a 
Pulse Width Modulation (PWM) signal to the Enable line. 
The shorter the pulse width, the slower the motor will spin.
 */



EasyTransfer ETin, ETout; 
// Motor A
int enA = 9; //PWM
int in1 = 8;
int in2 = 7;

// Motor B
int enB = 3; //PWM
int in3 = 5;
int in4 = 4;

// Motor C Elevation
int enC = 10; //PWM
int in5 = 11;
int in6 = 12;

int joyposVRy = 512;
int joyposVRx = 512;
int joyposElev = 512;


struct RECEIVE_DATA_STRUCTURE{
  //put your variable definitions here for the data you want to receive
  //THIS MUST BE EXACTLY THE SAME ON THE OTHER ARDUINO
  
  int joyVRy;
  int joyVRx;
  int joyElev;
};

struct SEND_DATA_STRUCTURE{
};

//give a name to the group of data
RECEIVE_DATA_STRUCTURE rxdata;
SEND_DATA_STRUCTURE txdata;

// Motor Speed Values - Start at zero
int MotorSpeed1 = 0;
int MotorSpeed2 = 0;
int MotorSpeed3 = 0;


void setup() {
  // put your setup code here, to run once:
  Serial.begin(9600);
  //start the library, pass in the data details and the name of the serial port. Can be Serial, Serial1, Serial2, etc.
  ETin.begin(details(rxdata), &Serial);
  ETout.begin(details(txdata), &Serial);
  

// Set all the motor control pins to outputs
  pinMode(enA, OUTPUT);
  pinMode(in1, OUTPUT);
  pinMode(in2, OUTPUT);

  pinMode(enB, OUTPUT);
  pinMode(in3, OUTPUT);
  pinMode(in4, OUTPUT);

  pinMode(enC, OUTPUT); //Z axis elevation
  pinMode(in5, OUTPUT); //Z axis elevation
  pinMode(in6, OUTPUT); //Z axis elevation
  



   // Start with motors disabled and direction forward
  
  // Motor A
  
  digitalWrite(enA, LOW);
  digitalWrite(in1, HIGH);
  digitalWrite(in2, LOW);

   // Motor B
  
  digitalWrite(enB, LOW);
  digitalWrite(in3, HIGH);
  digitalWrite(in4, LOW);

   // Motor C
  
  digitalWrite(enC, LOW);
  digitalWrite(in5, HIGH);
  digitalWrite(in6, LOW);
}

void loop() {
  
 //then we will go ahead and send that data out
  ETout.sendData();
  
  for(int i=0; i<5; i++){
    //remember, you could use an if() here to check for new data, this time it's not needed.
    ETin.receiveData();

  // Read the values from the potentiometers

joyposVRy = rxdata.joyVRy;  //Y axis Vertical on joystick
joyposVRx = rxdata.joyVRx;  //X axis Horizontal on joystick
joyposElev = rxdata.joyElev; //Z axis up and down elevation


  // Determine if this is a forward or backward motion
  // Do this by reading the Verticle Value
  // Apply results to MotorSpeed and to Direction

 if (joyposVRy < 460)
 {
    // This is Backward

    // Set Motor A backward

    digitalWrite(in1, LOW);
    digitalWrite(in2, HIGH);

    // Set Motor B backward

    digitalWrite(in3, LOW);
    digitalWrite(in4, HIGH);

    //Determine Motor Speeds

    // As we are going backwards we need to reverse readings

    joyposVRy = joyposVRy - 460; // This produces a negative number
    joyposVRy = joyposVRy * -1;  // Make the number positive

    MotorSpeed1 = map(joyposVRy, 0, 460, 0, 255);
     MotorSpeed2 = map(joyposVRy, 0, 460, 0, 255);
    
  }
  else if (joyposVRy > 564)
  {
    // This is Forward

    // Set Motor A forward

    digitalWrite(in1, HIGH);
    digitalWrite(in2, LOW);

    // Set Motor B forward

    digitalWrite(in3, HIGH);
    digitalWrite(in4, LOW);

    //Determine Motor Speeds

    MotorSpeed1 = map(joyposVRy, 564, 1023, 0, 255);
    MotorSpeed2 = map(joyposVRy, 564, 1023, 0, 255);

  }
  else
  {
    // This is Stopped

    MotorSpeed1 = 0;
    MotorSpeed2 = 0; 

  }

  ///---Steering --//
  // Now do the steering
  // The Horizontal position will "weigh" the motor speed
  // Values for each motor

  if (joyposVRx < 460)
  {
    // Move Left

    // As we are going left we need to reverse readings

    joyposVRx = joyposVRx - 460; // This produces a negative number
    joyposVRx = joyposVRx * -1;  // Make the number positive

    // Map the number to a value of 255 maximum

    joyposVRx = map(joyposVRx, 0, 460, 0, 255);
        

    MotorSpeed1 = MotorSpeed1 - joyposVRx;
    MotorSpeed2 = MotorSpeed2 + joyposVRx;

    // Don't exceed range of 0-255 for motor speeds

    if (MotorSpeed1 < 0)MotorSpeed1 = 0;
    if (MotorSpeed2 > 255)MotorSpeed2 = 255;

  }
  else if (joyposVRx > 564)
  {
    // Move Right

    // Map the number to a value of 255 maximum

    joyposVRx = map(joyposVRx, 564, 1023, 0, 255);
        

    MotorSpeed1 = MotorSpeed1 + joyposVRx;
    MotorSpeed2 = MotorSpeed2 - joyposVRx;

    // Don't exceed range of 0-255 for motor speeds

    if (MotorSpeed1 > 255)MotorSpeed1 = 255;
    if (MotorSpeed2 < 0)MotorSpeed2 = 0;      

  }

    //---Up/Down---//

 if (joyposElev < 460)
 {
    // This is Down
    // Set Motor C backward
    
  digitalWrite(in5, LOW);
    digitalWrite(in6, HIGH);
    
     //Determine Motor Speeds
 // As we are going backwards we need to reverse readings
    joyposElev = joyposElev - 460; // This produces a negative number
    joyposElev = joyposElev * -1;  // Make the number positive

    MotorSpeed3 = map(joyposElev, 0, 460, 0, 255);

    
  }
  else if (joyposElev > 564)
  {
    // This is UP
    // Set Motor C forward

    digitalWrite(in5, HIGH);
    digitalWrite(in6, LOW);

    //Determine Motor Speeds
  
      MotorSpeed3 = map(joyposElev, 564, 1023, 0, 255);

  }
  else
  {
    // This is Stopped

  MotorSpeed3 = 0;

  }
  
  
  // Adjust to prevent "buzzing" at very low speed
  
 if (MotorSpeed1 < 8){
    MotorSpeed1 = 0;
    }
    
if (MotorSpeed2 < 8){
    MotorSpeed2 = 0;
    }

  if (MotorSpeed3 < 8){
    MotorSpeed3 = 0;
    }
  // Set the motor speeds

  analogWrite(enA, MotorSpeed1);
  analogWrite(enB, MotorSpeed2);
  analogWrite(enC, MotorSpeed3);
  
}
}




